View Source QuickFSPublicAPI.Api.Companies (quick_fs_public_api v0.0.2)

API calls for all endpoints tagged Companies.

Link to this section Summary

Functions

List Supported Companies Returns a list of ticker symbols supported by QuickFS.net. You may optionally specify a country code (US, CA, MM, AU, NZ, or LN) and an exchange.

List Recently-Updated Companies Returns a list of ticker symbols that were updated with new financial data on or after the specified date (formatted as YYYYMMDD). You may optionally specify a country code (US, CA, MM, AU, NZ, or LN).

Link to this section Functions

Link to this function

companies_country_exchange_get(connection, country, exchange, opts \\ [])

Specs

companies_country_exchange_get(
  Tesla.Env.client(),
  String.t(),
  String.t(),
  keyword()
) ::
  {:ok, QuickFSPublicAPI.Model.RequestError.t()}
  | {:ok, QuickFSPublicAPI.Model.CompaniesList.t()}
  | {:error, Tesla.Env.t()}

List Supported Companies Returns a list of ticker symbols supported by QuickFS.net. You may optionally specify a country code (US, CA, MM, AU, NZ, or LN) and an exchange.

Parameters

  • connection (QuickFSPublicAPI.Connection): Connection to server
  • country (String.t):
  • exchange (String.t):
  • opts (KeywordList): [optional] Optional parameters

    Returns

on success {:error, Tesla.Env.t} on failure

Link to this function

companies_updated_date_country_get(connection, date, country, opts \\ [])

Specs

companies_updated_date_country_get(
  Tesla.Env.client(),
  String.t(),
  String.t(),
  keyword()
) ::
  {:ok, QuickFSPublicAPI.Model.RequestError.t()}
  | {:ok, QuickFSPublicAPI.Model.CompaniesList.t()}
  | {:error, Tesla.Env.t()}

List Recently-Updated Companies Returns a list of ticker symbols that were updated with new financial data on or after the specified date (formatted as YYYYMMDD). You may optionally specify a country code (US, CA, MM, AU, NZ, or LN).

Parameters

  • connection (QuickFSPublicAPI.Connection): Connection to server
  • date (String.t):
  • country (String.t):
  • opts (KeywordList): [optional] Optional parameters

    Returns

on success {:error, Tesla.Env.t} on failure