View Source QuickFSPublicAPI.Deserializer (quick_fs_public_api v0.0.2)
Helper functions for deserializing responses into models
Link to this section Summary
Functions
Update the provided model with a deserialization of a nested value
Link to this section Functions
Specs
Update the provided model with a deserialization of a nested value